//
//  DeliveryStatusViewController.swift
//  iDeliverMobileCD
//
//  Created by Kevin McNeish on 1/2/15.
//  Copyright (c) 2015 Oak Leaf Enterprises, Inc. All rights reserved.
//

import UIKit

protocol DeliveryStatusDelegate {
    
	func updateDeliveryStatus(deliveryStatus: DeliveryStatusEntity)
}

class DeliveryStatusViewController: UITableViewController {
    
    var delegate: DeliveryStatusDelegate?
    var shipmentEntity: ShipmentEntity!
    var deliveryStatus = DeliveryStatus()
    var deliveryStatusList = Array<DeliveryStatusEntity>()

    override func viewDidLoad() {
        super.viewDidLoad()

        // Share the shipment entity object context
        self.deliveryStatus.managedObjectContext =
            self.shipmentEntity.managedObjectContext
        
        self.deliveryStatusList =
        	self.deliveryStatus.getAllEntities()
    }

    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }

    // MARK: - Table view data source

    override func numberOfSectionsInTableView(tableView: UITableView) -> Int {
        // Return the number of sections.
        return 1
    }

    override func tableView(tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        // Return the number of rows in the section.
        return self.deliveryStatusList.count
    }
    
    override func tableView(tableView: UITableView, cellForRowAtIndexPath indexPath: NSIndexPath) -> UITableViewCell {
        
        let cell = tableView.dequeueReusableCellWithIdentifier("DeliveryStatusCell", forIndexPath: indexPath) as UITableViewCell

        // Configure the cell...
        let deliveryStatusEntity = self.deliveryStatusList[indexPath.row]
        
        var lblStatus = cell.viewWithTag(1) as UILabel
        lblStatus.text = deliveryStatusEntity.statusDescription
        
        var imgStatus = cell.viewWithTag(2) as UIImageView
        
        switch indexPath.row {
            
        	case 0:
              imgStatus.image = UIImage(named: "TruckBlack")
            
        	case 1:
            imgStatus.image = UIImage(named: "TruckRed")
            
        	case 2:
            imgStatus.image = UIImage(named: "TruckGreen")
            
        	default:
            	break
        }
        
        // Add a check mark if this is the currently selected item
        if deliveryStatusEntity.statusDescription == self.shipmentEntity.deliveryStatus.statusDescription {
            cell.accessoryType = UITableViewCellAccessoryType.Checkmark
        }

        return cell
    }

    override func tableView(tableView: UITableView, didSelectRowAtIndexPath indexPath: NSIndexPath) {
        
        if let oldRow = find(deliveryStatusList, self.shipmentEntity.deliveryStatus) {
            
            // Uncheck the previously checked cell
            var oldIndexPath = NSIndexPath(forRow: oldRow, inSection: 0)
            var cell = tableView.cellForRowAtIndexPath(oldIndexPath)
            cell?.accessoryType = UITableViewCellAccessoryType.None
            
            // Check the currently selected cell
            cell = tableView.cellForRowAtIndexPath(indexPath)
            cell?.accessoryType = UITableViewCellAccessoryType.Checkmark
            
            // Get the new delivery status
            var deliveryStatusEntity = deliveryStatusList[indexPath.row]
            self.shipmentEntity.deliveryStatus = deliveryStatusEntity
            
            // Tell the delegate to update the delivery status
            self.delegate?.updateDeliveryStatus(deliveryStatusEntity)
        }
    }
}
